==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/compagnon/lang/compagnon_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/compagnon?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'c_accueil_bienvenue' => 'Benvengut @nom@ !',
	'c_accueil_configurer_site' => 'Counfigurà lou vouòstre sit',
	'c_accueil_configurer_site_texte' => 'Una dei premièra caua da faire es de douna un noum au vouòstre sit.
		Si souòna atualamen « @nom@ ». Lou noum dóu sit es afichat aquì damount sus aquela pàgina.
		En clicant desoubre, pourès moudificà lou siéu noum, mà finda lì douna un logou e un eslougan.',
	'c_accueil_publication' => 'Publicàs !',
	'c_accueil_publication_texte' => 'Da publicà una pàgina, vi caurà creà un article.
		Per acò, es necessari de creà au màncou una rùbrica. Poudès lou faire en lou menù « Edicioun » en clicant soubre « Rùbrica ».',
	'c_accueil_texte' => 'Venès d’intrà en l’espaci privat de SPIP.',
	'c_accueil_texte_revenir' => '		Aquela pàgina presenta l’atività editouriala rechenta sus lou vouòstre sit.
		Poudès sempre tournà sus aquela pàgina en clicant sus l’icona de maioun,
		dessamoun, souta lou vouòstre noum.',
	'c_article_redaction' => 'L’article es en cours de redacioun',
	'c_article_redaction_redacteur' => 'L’article es en cours de redacioun',
	'c_article_redaction_redacteur_texte' => 'Per proupausa lou vouòstre article ai aministratour dóu sit e ai autre redatour,
		en lou cadre sus lou coustà, cambiàs « en cours de redacioun » da « proupausat da publicacioun ».',
	'c_article_redaction_texte' => 'Da publicà aquel article sus lou sit public, cau cambià lou siéu statut.
		En lou cadre sus lou coustà, cambiàs « en cours de redacioun » da « publicat en ligna ».',
	'c_articles_creer' => 'Couma creà un article ?',
	'c_articles_creer_texte' => 'Noun poudès creà un article da aquela pàgina
		que s’esista una rùbrica en lou vouòstre sit.
		Poudès la creà dau menù « Edicioun », pi « Rùbrica ».',
	'c_job' => 'Lu travai da faire…',
	'c_job_texte' => 'Aquela pàgina lista li tacha de mantenença venent
		que SPIP dèu efetuà. Aqueli tacha soun esecutadi da intervàlou régulié
		o pountualamen dai tratamen pèuge demandat dai plugin,
		couma l’espedissioun d’e-mail en massa.',
	'c_rubrique_publier' => 'Creàs un article',
	'c_rubrique_publier_texte' => 'Una rùbrica es visible sus lou sit public
		que coura counten au màncou un countegut publicat ; per isemple : un article publicat.
		Creàs pi un article. Poudès lou faire despì aquela pàgina, souta lou descritiéu de la vouòstra rùbrica.',
	'c_rubriques_creer' => 'Creàs una premièra rùbrica !',
	'c_rubriques_creer_texte' => 'Li rùbrica soun la counstrutura da basa dóu sit ; pourès creà dei article en caduna tra eli.
		Coumençàs da creà una premièra rùbrica.',
	'c_sites_creer' => 'Couma creà o empourtà un sit ?',
	'c_sites_creer_texte' => 'Pourès creà o empourtà un sit despì esta pàgina que s’esiste una rùbrica en lou vouòstre sit.
		Poudès la creà dau menù « Edicioun », pi « Rùbrica ».',

	// E
	'explication_activer_compagnon' => 'Lou coumpàgnou ajustà dei coumentari sus certeni pàgina
			de l’espaci privat da ajudà a pilha SPIP en main. Vouriàs l’ativà ?',
	'explication_reinitialiser_compagnon' => 'Lu message jà vist d’un autour seran plus afichat après.
			Vouriàs reinicialisat aquelu message ?',

	// L
	'label_activer_compagnon' => 'Ativà lou coumpàgnou ?',
	'label_reinitialiser_compagnon' => 'Reinicialisà lu message dóu coumpàgnou ?',

	// O
	'ok' => 'OK',
	'ok_bien' => 'Ben !',
	'ok_jai_compris' => 'Ai capich !',
	'ok_merci' => 'Mercì',
	'ok_parfait' => 'Perfet !',

	// R
	'reinitialisation' => 'Reinicialisacioun',
	'reinitialisation_ok' => 'La reinicialisacioun es facha.',
	'reinitialiser' => 'Reinicialisà',
	'reinitialiser_moi' => 'Ahì, basta aquelu qu’ai jà legit',
	'reinitialiser_tous' => 'Ahì, quau sigue l’autour',

	// T
	'titre_compagnon' => 'Lou Coumpàgnou',
	'titre_page_configurer_compagnon' => 'Counfigurà lou le Coumpàgnou'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/compagnon/lang/compagnon_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/compagnon?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'c_accueil_bienvenue' => 'Benvengut @nom@ !',
	'c_accueil_configurer_site' => 'Counfigurà lou vouòstre sit',
	'c_accueil_configurer_site_texte' => 'Una dei premièra caua da faire es de dounà un noum au vouòstre sit.
		Si souòna atualamen « @nom@ ». Lou noum dóu sit es afichat aquì damount sus aquela pàgina.
		En clicant desoubre, pourès moudificà lou siéu noum, mà finda lì douna un logou e un eslougan.',
	'c_accueil_publication' => 'Publicàs !',
	'c_accueil_publication_texte' => 'Per publicà una pàgina, vi caurà creà un article.
		Per acò, es nechessari de creà au màncou una rùbrica. Poudès lou faire en lou menù « Edicioun » en clicant soubre « Rùbrica ».',
	'c_accueil_texte' => 'Venès d’intrà en l’espaci privat de SPIP.',
	'c_accueil_texte_revenir' => '		Aquela pàgina presenta l’atività editouriala rechenta sus lou vouòstre sit.
		Poudès sempre tournà soubre aquela pàgina en clicant sus l’icona de maioun,
		dessamoun, souta lou vouòstre noum.',
	'c_article_redaction' => 'L’article es en cours de redacioun',
	'c_article_redaction_redacteur' => 'L’article es en cours de redacioun',
	'c_article_redaction_redacteur_texte' => 'Per proupausa lou vouòstre article ai aministratour dóu sit e ai autre redatour,
		en lou cadre sus lou coustà, cambiàs « en cours de redacioun » da « proupausat da publicacioun ».',
	'c_article_redaction_texte' => 'Da publicà aquel article sus lou sit public, cau cambià lou siéu statut.
		En lou cadre sus lou coustà, cambiàs « en cours de redacioun » da « publicat en ligna ».',
	'c_articles_creer' => 'Couma creà un article ?',
	'c_articles_creer_texte' => 'Noun poudès creà un article da aquela pàgina
		que s’esista una rùbrica en lou vouòstre sit.
		Poudès la creà dau menù « Edicioun », pi « Rùbrica ».',
	'c_job' => 'Lu travai da faire…',
	'c_job_texte' => 'Aquela pàgina lista li tacha de mantenença venent
		que SPIP dèu efetuà. Aqueli tacha soun esecutadi da intervàlou régulié
		o pountualamen dai tratamen pèuge demandat dai plugin,
		couma l’espedissioun d’e-mail en massa.',
	'c_rubrique_publier' => 'Creàs un article',
	'c_rubrique_publier_texte' => 'Una rùbrica es visible sus lou sit public
		que coura counten au màncou un countegut publicat ; per isemple : un article publicat.
		Creàs pi un article. Poudès lou faire despì aquela pàgina, souta lou descritiéu de la vouòstra rùbrica.',
	'c_rubriques_creer' => 'Creàs una premièra rùbrica !',
	'c_rubriques_creer_texte' => 'Li rùbrica soun la counstrutura da basa dóu sit ; pourès creà dei article en caduna tra eli.
		Coumençàs da creà una premièra rùbrica.',
	'c_sites_creer' => 'Couma creà o empourtà un sit ?',
	'c_sites_creer_texte' => 'Pourès creà o empourtà un sit despì esta pàgina que s’esiste una rùbrica en lou vouòstre sit.
		Poudès la creà dau menù « Edicioun », pi « Rùbrica ».',

	// E
	'explication_activer_compagnon' => 'Lou coumpàgnou ajustà dei coumentari sus certeni pàgina
			de l’espaci privat da ajudà a pilha SPIP en main. Vouriàs l’ativà ?',
	'explication_reinitialiser_compagnon' => 'Lu message jà vist d’un autour seran plus afichat après.
			Vouriàs reinicialisat aquelu message ?',

	// L
	'label_activer_compagnon' => 'Ativà lou coumpàgnou ?',
	'label_reinitialiser_compagnon' => 'Reinicialisà lu message dóu coumpàgnou ?',

	// O
	'ok' => 'OK',
	'ok_bien' => 'Ben !',
	'ok_jai_compris' => 'Ai capich !',
	'ok_merci' => 'Mercì',
	'ok_parfait' => 'Perfet !',

	// R
	'reinitialisation' => 'Reinicialisacioun',
	'reinitialisation_ok' => 'La reinicialisacioun es facha.',
	'reinitialiser' => 'Reinicialisà',
	'reinitialiser_moi' => 'Ahì, basta aquelu qu’ai jà legit',
	'reinitialiser_tous' => 'Ahì, quau sigue l’autour',

	// T
	'titre_compagnon' => 'Lou Coumpàgnou',
	'titre_page_configurer_compagnon' => 'Counfigurà lou le Coumpàgnou'
);

?>
